LogoType enum

Inheritance
Available extensions

Values

bcel → const LogoType
jdb → const LogoType
ldb → const LogoType
maruhan → const LogoType
mixay → const LogoType
ans → const LogoType
hal → const LogoType
acle → const LogoType
ib → const LogoType
mepom → const LogoType
bic → const LogoType
hiapp → const LogoType
icbbc → const LogoType
kbank → const LogoType
lvd → const LogoType
mmoney → const LogoType
vtb → const LogoType

Properties

asset String

Available on LogoType, provided by the LogoTypeExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on LogoType, provided by the LogoTypeExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogoType>
A constant List of the values in this enum, in order of their declaration.